@@ -13,9 +13,8 @@ use FormValidator::LazyWay::Result;
 use UNIVERSAL::require;
 use Carp;
 use Data::Dumper;
-use Data::Visitor::Encode;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 __PACKAGE__->mk_accessors(qw/config unicode rule message fix filter result_class/);
 
@@ -45,6 +44,7 @@ sub new {
     }
 
     if ( $self->unicode || $self->{config}->{unicode} ) {
+        Data::Visitor::Encode->require or die 'unicode option require Data::Visitor::Encode. Please Install it.';
         my $dev = Data::Visitor::Encode->new();
         $self->config( $dev->decode('utf8', $self->config) );
     }
